#!/bin/csh

#Shijun Zhong, July, 2007
#---This script generates sphere clusters on protein surface 
#   and evaluates the binding sites using the Binding Response method.
#
#Usage: ThisScript 
#or:    ThisScript protein.pdb protein.mol2
#
#   You should already installed the following programs:
#   DMS (dms), DOCK4 (sphgen, showbox, grid, dock), and CHARMM (charmm)
#   You may copy these executable files to ../bin/ so that you don't need to
#   change the following path.
#
#   In your work directory ../test/, you should have two protein structure files:
#   protein.pdb  which does not contain hydrogen atoms, and
#   protein.mol2 which contains hydrogens and atomic partial charges
#
###############################################################################
#   User may change the paths, the number of top sites, and ligand file:
set charmm = ../bin/charmm
set dms = ../bin/dms
set sphgen = ../bin/sphgen
set showbox = ../bin/showbox
set grid = ../bin/grid
set dock = ../bin/dock
set TOP = 10
set ligand = ligand1000.mol2
#   The ligand file ligand1000.mol2 should be placed in directory ../parameter/
###############################################################################

##################
#---Step 1
##################
#---To get the protein structure files
set pdb = protein.pdb
set mol2 = protein.mol2
  if ( $#argv == 2 ) then
set pdb = $1
set mol2 = $2
  endif

##################
#---Steps 2 and 3
##################
#---To generate protein surface and the complementary spheres on the surface
#../bin/gen_sph.csh 
../bin/gen_sph.csh $pdb $dms $sphgen 

#---To extract the clustered spheres from the SPHGEN-generated sphere file. 
#   The input pdbid.sph is generated by the previous step.
../bin/sph_cut.pl pdbid.sph

#---To transfer SPH file to CRD file for CHARMM clustering.
#   The input pdbid_cut.sph is generated by the previous step.
../bin/sph2crd.csh pdbid_cut.sph

##################
#---Step 4
##################
#---To re-cluster the spheres using CHARMM
cp ../parameter/clustst5.inp .
$charmm < clustst5.inp > clustst5.out

##################
#---Steps 5 and 6
##################
#---To pick up the top clusters
../bin/get_top_cluster.csh $TOP $showbox

#---To clean up
if ( -d ref ) then
rm -rf ref
endif
mkdir ref
mv clust* pdbid* top_sets.id ref

##################
#---Step 7
##################
#---To do docking. This step might take 60 hours of CPU time.
#---User may run docking separately and copy the output *.mol2 to ./top_clust/
../bin/grid2dock.csh $grid $dock $ligand $mol2 $TOP

##################
#---Step 8
##################
#---To evaluate the top binding sites using the Binding Response method
../bin/score.csh br.out $TOP $ligand

