#!/bin/csh
#Shijun Zhong, August, 2007
#---To evaluate the Binding Response values of the selected binding sites.
 setenv LC_ALL C

set OUT = br.out
set TOP = 10
set ligand = ligand1000.mol2
  if ( $#argv == 3 ) then
set OUT = $1
set TOP = $2
set ligand = $3 
  endif

set PDBID = pdbid
set DIR = top_clust

echo "User `echo $USER` computed on `date`" > $OUT
echo "" >>$OUT
echo "                    Binding Response (BR)" >> $OUT
echo "" >>$OUT
echo "Reference: \
   Shijun Zhong and Alexander D. MacKerell, \
   Binding Response: A Descriptor for Selecting Ligand Binding Site \
   on Protein Surfaces. J. Chem. Inf. Model. 2007, 47, 2303-2315." >> $OUT

echo "" >> $OUT
set N = `grep "<TRIPOS>MOLE" ../parameter/$ligand | wc -l | awk '{print $1}'`
echo "$TOP top binding sites evaluated based on the binding energy and pose of" >> $OUT
echo "$N ligands docked against each of these binding sites." >> $OUT
set OPTION = 1
if ( $N >= 100 ) then
set OPTION = 2
@ subset = ($N * 9) / 10
echo "A subset of $subset ligands was used to calculate the BR values." >> $OUT
endif

echo "" >> $OUT
echo "The location of each binding site can be viewed by a structure viewer, \
like RASMOL or VMD, using the protein PDB file and the cluster PDB files \
in the subdirectory ./top_clust/" >> $OUT

echo "" >> $OUT
echo "Preferred binding sites will have a larger BR value \
as given in the last column of the following table." >> $OUT


rm -f tmp
set i = 1
while ( $i <= $TOP )
set M = `grep "<TRIPOS>MOLE" $DIR/${PDBID}_dock_$i.mol2 | wc -l | awk '{print $1}'`
if ( $M != $N ) echo "Warning: only $M ligands in ${PDBID}_dock_$i.mol2 file" >> $OUT
echo "$DIR/${PDBID}_dock_$i.mol2" > in
echo "$DIR/${PDBID}_clust_$i.sph" >> in
../bin/br.exe < in > $DIR/br_$i.out
set NSPH = `tail -1 $DIR/${PDBID}_clust_$i.sph | awk '{print $1}'`
set Eav = `tail -1 $DIR/br_$i.out | awk '{print $2}'` 
set BR  = `tail -1 $DIR/br_$i.out | awk '{print $3}'`
if ( $OPTION == 2 ) then
awk '{if(NF==10) print $6}' $DIR/${PDBID}_dock_$i.rnk | sort -nr -k 1 | head -$subset > sub
set BRSUB = `awk 'BEGIN{a=0; b=0} {a=a+1; b=b+$1} END{print b/a}' sub`
echo "${PDBID}_clust_$i $NSPH $Eav $BR $BRSUB" >> tmp
else 
echo "${PDBID}_clust_$i $NSPH $Eav $BR" >> tmp
endif

@ i++
end

echo "" >> $OUT
if ( $OPTION == 2 ) then
echo "Binding_Site    Spheres  E_averaged BR(all_ligands) BR(90%_subset)" >> $OUT
sort -nr -k 5 tmp > sub
awk '{printf"%-15s%8s%12s%16s%15s\n",$1,$2,$3,$4,$5}' sub >> $OUT
else
echo "Binding_Site    Spheres  E_averaged BR(all_ligands)" >> $OUT
sort -nr -k 4 tmp > sub
awk '{printf"%-15s%8s%12s%16s\n",$1,$2,$3,$4}' sub >> $OUT
endif
rm -f tmp sub in fort.7

