CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C Shijun Zhong, July, 2007
C
C                      br.f (Binding Response)
C
C     This program computes the binding response of a binding pocket
C     to a set of probe compounds, based on the docking result.
C     The binding response values can be used to compare binding sites 
C     for selecting an ideal site for virtual database screening. The
C     binding response values are designed to be in the range [0, 1]. A
C     good binding site should receive a larger binding response value.
C
C     Before using this program, a test docking should be performed. A
C     mol2 file should be generated using DOCK4.0 and a sph file in the
C     SPHGEN output format should be generated to define the shape of
C     the binding pocket.
C
C COMPILATION
C     g77 -O br.f -o br.exe
C
C RUN
C     ./br.exe < ex1.inp > ex1.out
C
C INPUT
C     The input requires only two file names in separate lines, i.e.
C         DOCK4-generated.mol2
C         SPHGEN-format.sph
C     The mol2 file, generated by DOCK4.0, contains the compound name,
C     the interaction energy, and the coordinates.
C     The sph file, in the format of SPHGEN output, defines the
C     effective space of the binding pocket. It should be pointed out
C     that the sphere set can be different from that used in docking.
C
C OUTPUT
C     The output gives the averaged binding response value (BR) for the
C     first 10 compounds, the first 100 compounds,... and all compounds.
C     Ligand_N    E_aver      BR
C         10    -34.4760      0.9985
C        100    -28.7006      0.9729
C        108    -27.9581      0.9663
C     So, the Binding Response value is 0.9663 for the 108 docked
C     compounds (ex1.mol2) on the binding site defined by 
C     the sphere set (ex1.sph).
C
C REFERENCE
C     Shijun Zhong and Alexander D. MacKerell,
C     "Binding Response: A Descriptor for Selecting Ligand Binding Site
C                        on Protein Surfaces",
C     J. Chem. Inf. Model., 2007, 47(6), 2303-2315.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      implicit real*8 (a-h,o-z)
      character*80 Recept,Mol2,Sph,Outpdb,Outrnk,ch,CMP
      dimension S(1000),Bhalf(100)
      logical cond
25    format(T25,A80)
251   format(T26,A80)
57    format(T57,F7.2)
571   format(T58,F7.2)
66    format("Ligand_N    E_aver      BR")
67    format(I6,3F12.4,2x,8F10.4)
70    format(A6,I5,2x,A4,A3,2x,I4,4x,3F8.3,2x,"1.00",2F6.2)
75    format("COMPND",4x,70A)
77    format("REMARK",7x,"No   Total     VDW  interE  interR  interA")
78    format("REMARK",I9,5F8.2,1x,40A)
80    format(A80)
85    format(A50,F20.4)
88    format(80A)
      B=0.5
      Bhalf(1)=0.5
      do i=2,100
      B=B*0.5
      Bhalf(i)=Bhalf(i-1)+B
      enddo

C-----basic input
      Iprint=0                ! Iprint=0 for limited print
C     read(*,*) Iprint        ! Iprint=1 for printing more
      read(*,80) Mol2         ! DOCK4 generated mol2 file
      read(*,80) Sph          ! SPHGEN generated sph file

C-----parameter setup
      Ipara=0                 ! =0 for default parameters
C     read(*,*) Ipara         ! =1 for user defined parameters
      IMolB=5                 ! the way to represent molecular size
      NBref=12                ! the reference number for pocket size
      Eref=-30.0              ! the reference interaction energy
      rateNB=32               ! the tuning factor for N
      rateE=8                 ! the tuning factor for E
      rateDB=3                ! power of (Dout/Rmol)**rateDB
      Rsph=1.4                ! radius of sphere. Don't change it
      if(Ipara.eq.1) then
C     read(*,*) IMolB
      read(*,*) NBref
      read(*,*) Eref
      read(*,*) rateNB
      read(*,*) rateE
      read(*,*) rateDB
C     read(*,*) Rsph
      if(NBref.lt.1) then
      write(*,*) '(NBref .lt. 1) stop!'
      stop
      endif
      endif

      call bspace(Mol2,nMol2)
      call espace(Mol2,nMol2)
      nrnk=nMol2-4
      Outrnk(1:nrnk)=Mol2(1:nrnk)
      Outrnk((nrnk+1):(nrnk+3))="rnk"
      nrnk=nrnk+3
      call bspace(Sph,nSph)
      call espace(Sph,nSph)

601   format(/"IMolB =the way to represent the molecular size",I2,
     &/"NBref =the reference number for pocket size",I3,
     &/"Eref =the reference energy",F8.2,
     &/"rateNB=the tuning factor for N",F8.2,
     &/"rateE=the tuning factor for E",F8.2,
     &/"rateDB=the power of (Dout/Rmol)",F8.2)

      write(*,88) (Mol2(k:k),k=1,nMol2)
      write(*,88) (Sph(k:k),k=1,nSph)
C     write(*,601) IMolB,NBref,Eref,rateNB,rateE,rateDB
      write(*,66) 

      Iu1=1
      Iu2=2
      Iu3=3
      Iu4=4

      Open(Unit=Iu1, File=Mol2(1:nMol2), Status="Old")
      Open(Unit=Iu3, File=Sph(1:nSph), Status="Old")
      Open(Unit=Iu4, File=Outrnk(1:nrnk), Status="Unknown")
7621  format('NBref=',I2,3x,'Eref=',F6.2,3x,'rateE=',F4.1,3x,
     &'rateNB=',F4.1,3x,'rateDB=',F3.1)
98    format(I3,' spheres in: ',88A)
981   format(' Compound file: ',88A)
7622  format("         e      n    B1   -B2    B",
     &"     MW   Natom Nv Compound")

C-----reads spheres from Sph
C1234567890123456789012345678901234567890123456789012345
CDOCK 3.5 receptor_spheres
Ccluster     0   number of spheres in cluster   11
C 1608   7.33414  -5.36071  46.73737   1.704 1899 0  0
C 1609   4.55676  -7.10111  46.35265   3.092 1931 0  0
C 1616   6.81260  -5.12157  46.74300   1.645 1608 0  0
C 1617   5.85337  -5.46684  44.84464   1.876 1896 0  0
C 1618   3.01431  -4.38675  47.19300   1.398 1623 0  0
C 1623   2.90588  -5.32642  47.24284   1.796 1941 0  0
C 1902   4.61736  -5.11418  43.41630   1.500 1938 0  0
C 1937   1.90391  -6.25688  42.65905   1.674 1928 0  0
C 1938   4.67382  -5.41360  44.07272   1.900 1929 0  0
C 1940   1.24131  -6.48790  42.63695   2.075 1928 0  0
C 1941   2.46943  -6.59571  44.02111   2.088 1929 0  0
      read(Iu3,*)
      read(Iu3,"(T45,I6)") Itmp
      if(Itmp.lt.1) then
      write(*,*) 'no sphere, stop!'
      stop
      endif
      write(Iu4,7621) NBref,Eref,rateE,rateNB,rateDB
      write(Iu4,98) Itmp,(Sph(k:k),k=1,nSph)
      write(Iu4,981)     (Mol2(k:k),k=1,nMol2)
      write(Iu4,7622)
      S(1)=float(Itmp)
      DMM=0.0
      XS=0.0
      YS=0.0
      ZS=0.0
      do j=1,Itmp
      k1=2+4*(j-1)
      k4=k1+3
      read(Iu3,"(T6,3F10.5,F8.3)") (S(k),k=k1,k4)
      if(Rsph.gt.0.0) then
       DMM=DMM+1.0
       XS=XS+S(k1)
       YS=YS+S(k1+1)
       ZS=ZS+S(k1+2)
      else
      Rad=S(k4)
      DMM=DMM+Rad
      XS=XS+S(k1)*Rad  
      YS=YS+S(k1+1)*Rad
      ZS=ZS+S(k1+2)*Rad
      endif
      enddo
      XS=XS/DMM
      YS=YS/DMM
      ZS=ZS/DMM
      ks1=2+4*Itmp
      ks4=ks1+3
      S(ks1)  =XS
      S(ks1+1)=YS
      S(ks1+2)=ZS
      S(ks4)  =DMM/Itmp
      j=Itmp+1
      Dsph=0.0
      do j=1,Itmp
      k1=2+4*(j-1)
      k4=k1+3
        xo=S(k1)  -XS
        yo=S(k1+1)-YS
        zo=S(k1+2)-ZS
        Dtmp=SQRT(xo*xo+yo*yo+zo*zo)
        Dsph=Dsph+Dtmp+S(k1+3)
      enddo
      Dsph=Dsph/Itmp
      S(ks4+1)=Dsph

      Close(Unit=Iu3)

      Icnt=0
      Ipow=10
      SBR=0.0
      SEtot=0.0
      SVa=0.0
C######### Energy score                             :     -49.73
C########## Energy score                             :     -33.03
C########## Energy Score:          -42.260212
C##########    Grid Score:          -33.091320
100   read(Iu1,80,Err=150,End=200) ch
        Ign=0
      do i=3,15
      isite=i+11
      cond=ch(i:isite).eq."Energy Score"
     &     .or.ch(i:isite).eq."Energy score"
     &     .or.ch(i:isite).eq."  Grid Score"
      if(cond) then
        Ign=1
      j1=isite+1
      do j=j1,70
      if(ch(j:j).eq.":") then
        Open(Unit=7, Status="Unknown")
        write(7,80) ch(j+1:80)
        Close(Unit=7)
        Open(Unit=7, Status="Old")
        read(7,*) Etot
        Close(Unit=7)
        goto 110
      endif
      enddo
        write(*,*) 'improper mol2 format: no energy'
        stop
      endif
      enddo
      if(Ign.eq.0) goto 100

110   read(Iu1,80,Err=150,End=200) ch
      if(ch(1:17).ne."@<TRIPOS>MOLECULE") goto 110
      read(Iu1,80,Err=150,End=200) CMP
      call bspace(CMP,nCMP)
      call espace(CMP,nCMP)

      read(Iu1,*,Err=150,End=200) Natom,Nbond
      Nat2=(Natom*(Natom-1))/2
120   read(Iu1,80,Err=150,End=200) ch
      if(ch(1:13).ne."@<TRIPOS>ATOM") goto 120
      Icnt=Icnt+1

         If(Etot.lt.0.0) then
      call getmol(CMP,Icnt,Iu1,Iu2,Iu4,Natom,Nbond,Mol2,Sph,S,Dis,
     &            Etot,Nover,BR,IMolB,
     &            NBref,Eref,rateNB,rateE,Bhalf,
     &            Nat2,rateDB,Rsph)
         Else
      BR=0.0
      Etot=0.0
      Va=0.0
         Endif

C-----Mean 
      SBR=SBR+BR
      SEtot=SEtot+Etot
      SVa=SVa+Va

      if(Icnt.eq.Ipow) then
      BRav=SBR/Ipow
      Etotav=SEtot/Ipow
      Vaav=SVa/Ipow
C     write(*,67) Icnt,Etotav,Vaav,BRav
      write(*,67) Icnt,Etotav,BRav
      Ipow=Ipow*10
      endif

      goto 100

150   write(*,*) 'Error in reading input file'
      stop
200   continue
      BRav=SBR/Icnt
      Etotav=SEtot/Icnt
      Vaav=SVa/Icnt
C     write(*,67) Icnt,Etotav,Vaav,BRav
      write(*,67) Icnt,Etotav,BRav

      Close(Unit=Iu4)
      Close(Unit=Iu1)
      stop
      end

*Deck-Block (contains element data)
      BLOCK DATA
      implicit CHARACTER*2 (O)
      implicit real*8 (a-h,p-z)
      COMMON/OCHSYM/OCH(110)
      DATA OCH/'H ','He','Li','Be','B ','C ','N ','O ','F ','Ne','Na',
     3'Mg','Al','Si','P ','S ','Cl','Ar','K ','Ca','Sc','Ti','V ','Cr',
     4'Mn','Fe','Co','Ni','Cu','Zn','Ga','Ge','As','Se','Br','Kr','Rb',
     5'Cs','Y ','Zr','Nb','Mo','Tc','Ru','Rh','Pd','Ag','Cd','In','Sn',
     5'Sb','Te','I ','Xe','Cs','Ba','La','Ce','Pr','Nd','Pm','Sm','Eu',
     6'Gd','Tb','Dy','Ho','Er','Tm','Yb','Lu','Hf','Ta','W ','Re','Os',
     7'Ir','Pt','Au','Hg','Tl','Pb','Bi','Po','At','Rn','Fr','Ra','Ac',
     8'Th','Pa','U ','Np','Pu','Am','Cm','Bk','Cf','Es','Fm','Md','No',
     9'Lr','Rf','Db','Sg','Bh','Hs','Mt','Uu'/
      COMMON /ISTOPE/ ATW(110)
      DATA (ATW(I),I=1,84) /
     .            1.00783D0,  4.00260D0,  7.01600D0,  9.01218D0,
     111.00931D0, 12.00000D0, 14.00307D0, 15.99949D0, 18.99840D0,
     219.99244D0, 22.98977D0, 23.98504D0, 26.98154D0, 27.97693D0,
     330.97376D0, 31.97207D0, 34.96885D0, 39.96238D0, 38.96371D0,
     439.96259D0, 44.95591D0, 47.94795D0, 50.94396D0, 51.94051D0,
     554.93805D0, 55.93494D0, 58.93320D0, 57.93535D0, 62.93960D0,
     663.92915D0, 68.92558D0, 73.92118D0, 74.92159D0, 79.91652D0,
     778.91836D0, 83.91151D0, 84.91179D0, 87.90562D0, 88.90585D0,
     889.90470D0, 92.90638D0, 97.90541D0, 97.90722D0, 101.9043D0,
     9102.9055D0, 105.3035D0, 106.9051D0, 113.9034D0, 114.9039D0,
     1119.9022D0, 120.9038D0, 129.9063D0, 126.9045D0, 131.9041D0,
     2132.9054D0, 137.9052D0, 138.0963D0, 139.9054D0, 140.9076D0,
     3141.9077D0, 144.9127D0, 151.9197D0, 152.9212D0, 157.9241D0,
     4158.9253D0, 163.9292D0, 162.9287D0, 165.9303D0, 168.9342D0,
     5173.9389D0, 174.9408D0, 179.9465D0, 180.9480D0, 183.9509D0,
     6186.9557D0, 191.9615D0, 192.9629D0, 194.9648D0, 196.9665D0,
     7201.9706D0, 204.9744D0, 207.9766D0, 208.9804D0, 208.9824D0/
      DATA (ATW(I),I=85,110) /
     8209.9871D0, 210.9906D0, 223.0197D0, 226.0254D0, 227.0278D0,
     9232.0381D0, 231.0359D0, 238.0508D0, 237.0481D0, 244.0642D0,
     1243.0614D0, 247.0703D0, 247.0703D0, 251.0796D0, 252.0829D0,
     2257.0751D0, 257.0956D0,   1.0079D0,  8*0.000D0/
      END

*Deck-bspace
      Subroutine bspace(ch,n)
      character*80 ch
      character*1 NULL
      NULL=" "
      icnt=0
      do i=1,80
      if(ch(i:i).eq.NULL) then
         icnt=icnt+1
      else
         goto 100
      endif
      enddo
100   n=80-icnt
      if(n.eq.0) write(*,*) 'Warning: all string is space'
      do i=1,n
      j=i+icnt
      ch(i:i)=ch(j:j)   
      enddo
      j=n+1
      do i=j,80
      ch(i:i)=NULL
      enddo
      return
      end   

*Deck-Dalton
      Subroutine Dalton(Elemnt,Weight,Natom,Nc,Nh)
      IMPLICIT REAL*8 (A-H,P-Z)
      implicit character*2 (O)
      character*2 Elemnt(Natom)
      dimension Weight(Natom)
      COMMON/OCHSYM/OCH(110)
      COMMON /ISTOPE/ ATW(110)
      Nc=0
      Nh=0
      Do i=1,Natom
      do j=1,110
         if(Elemnt(i).eq.OCH(j)) then
         if(Elemnt(i).eq.OCH(1)) Nh=Nh+1
         if(Elemnt(i).eq.OCH(6)) Nc=Nc+1
         Weight(i)=ATW(j)
         goto 100
         endif
      enddo
100   continue
      Enddo
      return
      END

*Deck-espace
      Subroutine espace(ch,n)
      character*80 ch
      character*1 NULL,CtrlM
      NULL=" "
C---SGI machine can recongnize the end/return marker "
"
C       CtrlM="
"
      CtrlM=char(13)  
      icnt=0
      do i=1,80
      if(ch(i:i).eq.NULL) then
         icnt=icnt+1
      else
         icnt=0
      endif
      enddo
      n=80-icnt
      if(ch(n:n).eq.CtrlM) then
      ch(n:n)=NULL
      n=n-1
      endif
      return
      end 

*Deck-getmol
      Subroutine getmol(CMP,IM,Iu1,Iu2,Iu4,Natom,Nbond,Mol2,Sph,S,Dis,
     &            Etot,Nover,BR,IMolB,
     &            NBref,Eref,rateNB,rateE,Bhalf,
     &            Nat2,rateDB,Rsph)
      implicit real*8 (a-h,o-z)
      character*80 Mol2,Sph,ch,CMP
C     character*4 AtomID(Natom)
      character*2 Elemnt(Natom)
      character*1 OneDot, NULL
C     dimension x(Natom),y(Natom),z(Natom),charge(Natom),Weight(Natom)
      dimension x(Natom),y(Natom),z(Natom),Weight(Natom)
      dimension xp(1000),yp(1000),zp(1000),dp(Natom),Idp(1000),Ixp(1000)
      dimension IConn(9,Natom),ib(2,Nbond)
      dimension S(1000),Bhalf(100)
      dimension Dpair(Nat2)
      logical Partin
      OneDot="."
      NULL=" "
      NOne=1
      ONE=1.0
      ZERO=0.0
      do i=1,1000
      Idp(i)=0
      enddo
      call bspace(CMP,nCMP)
      call espace(CMP,nCMP)
C       write(*,*) 'in getmol'
C50    format(6x,A4,1x,3F10.4,1x,A2,13x,F8.4,6F12.2)
50    format(T12,3F10.4,1x,A2,13x,F8.4,6F12.2)
51    format(T17,3F10.4,1x,A2,13x,F8.4,6F12.2)
C50---678901234567890123456789012345678901234567890123456789012345678901234567890
C1     C10     11.7711   -8.2912   44.2393 C.ar    1  <1>   0.0100
C      5 C5         -2.0114   29.4838   22.2850 C.ar    1  <1>      0.1580
70    format(A6,I5,2x,A4,A3,I6,4x,3F8.3,2x,"1.00",2F6.2,I6)
760   format(I5,5F8.2,2I4,2F6.1,3F5.1,3F5.2,3F6.2,1x,
     &       2F5.1,3F5.2,2F8.2,2I4,1x,70A)
770   format(I5,5F8.2,I4,F6.2,3F5.2,2F8.2,2I4,1x,70A)
780   format(I5,4F8.2,I4,F6.2,F5.1,3F5.2,2F8.2,2I4,3F6.2,1x,70A)
790   format(8F6.1,1x,
     &       I5,4F8.2,I4,F6.2,F5.1,3F5.2,2F8.2,2I4,3F6.2,1x,70A)
C70---678901234567890123456789012345678901234567890123456789012345678901234567890
CATOM      1  N   MET A   1     -12.276  17.288  33.574  1.00 28.52           N
CATOM     25  CD2 LEU A   3      -5.462  18.821  29.413  1.00 20.47           C  
71    format("REMARK",4x,"Ntot Heavy Carbon Hydrogen MolWeight Charge",
     &       "  BR1   BR2   BR")
72    format("REMARK",4I7,3x,2F8.2,3F6.2)
73    format("REMARK",4x,"Nover Nsph Distance Diamet Radius"
     &      ," Etot  fOS  fDR  ftot   Eff")
74    format("REMARK",I9,I5,F7.2,F8.2,F6.2,F8.2,3F5.2,9F8.2)
80    format(A80)

      k=1+4*int(S(1))
      XS=S(k+1)
      YS=S(k+2)
      ZS=S(k+3)
      SRad=S(k+4)
      Dsph=S(k+5)

C-----reads the atom cards
      read(Iu1,80,Err=150,End=200) ch
      if(ch(16:16).ne.NULL) then
        Open(Unit=7,status="Unknown")
        write(7,80) ch
        Close(Unit=7)
        Open(Unit=7,status="Old")
        read(7,50,Err=150,End=200) x(1),y(1),z(1),Elemnt(1)
        if(Elemnt(1)(2:2).eq.OneDot) Elemnt(1)(2:2)=NULL
        Close(Unit=7)
        do i=2,Natom
        read(Iu1,50,Err=150,End=200) x(i),y(i),z(i),Elemnt(i)
        if(Elemnt(i)(2:2).eq.OneDot) Elemnt(i)(2:2)=NULL
        enddo
      else
        Open(Unit=7,status="Unknown")
        write(7,80) ch
        Close(Unit=7)
        Open(Unit=7,status="Old")
        read(7,51,Err=150,End=200) x(1),y(1),z(1),Elemnt(1)
        if(Elemnt(1)(2:2).eq.OneDot) Elemnt(1)(2:2)=NULL
        Close(Unit=7)
        do i=2,Natom
        read(Iu1,51,Err=150,End=200) x(i),y(i),z(i),Elemnt(i)
        if(Elemnt(i)(2:2).eq.OneDot) Elemnt(i)(2:2)=NULL
        enddo
      endif

      call Dalton(Elemnt,Weight,Natom,Nc,Nh)
      XX=0.0
      YY=0.0
      ZZ=0.0
      DMW=0.0
      Nover=0
C      Rad=1.4     ! radius for judging the overlap with a sphere, S(k4)
      if(Rsph.gt.0.0) then
        Rad=Rsph
      else
        Rad=SRad
      endif
      Itmp=int(S(1))
      Do i=1,Natom
      DMW=DMW+Weight(i)
      XX=XX+Weight(i)*x(i)
      YY=YY+Weight(i)*y(i)
      ZZ=ZZ+Weight(i)*z(i)
C---overlap with the sphere center
        xo=x(i)-XS
        yo=y(i)-YS
        zo=z(i)-ZS
        Dover=SQRT(xo*xo+yo*yo+zo*zo)
        dp(i)=Dover
        if(Dover.lt.Rad) then
        Nover=Nover+1
        xp(Nover)=x(i)
        yp(Nover)=y(i)
        zp(Nover)=z(i)
        Idp(i)=Itmp+1
        goto 120
        endif
C---overlap with the all spheres
        do j=1,Itmp
        k=2+4*(j-1)
        xo=x(i)-S(k)
        yo=y(i)-S(k+1)
        zo=z(i)-S(k+2)
C      Rad=S(k+3)     ! radius for judging the overlap with a sphere
C      Rad=1.4     ! radius for judging the overlap with a sphere, S(k4)
      if(Rsph.gt.0.0) then
        Rad=Rsph
      else
        Rad=S(k+3)
      endif
        Dover=SQRT(xo*xo+yo*yo+zo*zo)
C       Partin = Dover.lt.Rad.and.Elemnt(i)(1:1).ne."H"
        Partin = Dover.lt.Rad
        if(Partin) then
        Nover=Nover+1
        xp(Nover)=x(i)
        yp(Nover)=y(i)
        zp(Nover)=z(i)
        Ixp(Nover)=i
        if(Dover.lt.dp(i)) then
        dp(i)=Dover
        Idp(i)=j
        endif
        goto 120
        endif
        enddo
120   continue
      Enddo
      XX=XX/DMW
      YY=YY/DMW
      ZZ=ZZ/DMW
      L=9000+IM
C-----Dis=the distance from the center of mass to the center of the spheres
      DX=XX-XS
      DY=YY-YS
      DZ=ZZ-ZS
      Dis=DSQRT(DX*DX+DY*DY+DZ*DZ)
C-----Dout2=Shortest distance from the center of mass to the sphere surface
      Dout2=100.0
        do j=1,Itmp
        k=2+4*(j-1)
        xo=XX-S(k)
        yo=YY-S(k+1)
        zo=ZZ-S(k+2)
        Dover=SQRT(xo*xo+yo*yo+zo*zo)-S(k+3)
        if(Dover.lt.Dout2) Dout2=Dover
        enddo
C-----The radii from the center of mass of the ligand
      Rlrg=0.0          ! largest radius
      Rave=0.0          ! averaged radius
      Diam=0.0          ! largest interatomic distance
      Diav=0.0          ! averaged interatomic distance
      Ipair=0
      Natom1=Natom-1
      do i=1,Natom1
      xo=x(i)-XX
      yo=y(i)-YY
      zo=z(i)-ZZ
      Rtmp=SQRT(xo*xo+yo*yo+zo*zo)
      if(Rtmp.gt.Rlrg) Rlrg=Rtmp
      Rave=Rave+Rtmp
        i1=i+1
        do j=i1,Natom
        xo=x(i)-x(j)
        yo=y(i)-y(j)
        zo=z(i)-z(j)
        Rtmp=SQRT(xo*xo+yo*yo+zo*zo)
        Ipair=Ipair+1
        Dpair(Ipair)=Rtmp
        if(Rtmp.gt.Diam) Diam=Rtmp
        Diav=Diav+Rtmp
        enddo
      enddo
      xo=x(Natom)-XX
      yo=y(Natom)-YY
      zo=z(Natom)-ZZ
      Rtmp=SQRT(xo*xo+yo*yo+zo*zo)
      if(Rtmp.gt.Rlrg) Rlrg=Rtmp
      Rave=Rave+Rtmp
      Rave=Rave/Natom
      Diav=Diav*2.0/(Natom*(Natom-1))

C-----Dbind=The largest distance between bound atoms
      Dbind=0.0
      i1=Nover-1
      do i=1,i1
      j1=i+1
      do j=j1,Nover
        xo=xp(i)-xp(j)
        yo=yp(i)-yp(j)
        zo=zp(i)-zp(j)
        Rtmp=SQRT(xo*xo+yo*yo+zo*zo)
        if(Rtmp.gt.Dbind) then
        Dbind=Rtmp
        Iatom1=Ixp(i)
        Iatom2=Ixp(j)
        endif
      enddo
      enddo

C     if(IMolB.eq.5) RmolB=1.0*Rlrg
      RmolB=1.0*Rlrg

      Dsph=S(int(S(1))*4+6)
      DrefB=Dsph
      if(DrefB.lt.Dbind.and.Nover.gt.3) DrefB=Dbind
      Dout=Dis-DrefB
      if(Dout.lt.ZERO) Dout=0.0

      WE=0.0
      OneNeg=-1.0
      if(Etot.lt.OneNeg) WE=LOG(rateE*ABS(Etot))/LOG(rateE*ABS(Eref))
      if(WE.gt.1.0) WE=1.0
      Snorm1=0.0
      if(Nover.gt.0) Snorm1=log(rateNB*Nover)/log(rateNB*NBref)
      if(Snorm1.gt.1.0) Snorm1=1.0
      BR1=WE*Snorm1*Bhalf(Nover)
      BR2=0.0
      if(Dout.gt.ZERO) BR2=-(Dout/RmolB)**rateDB
      if(BR2.lt.-1.0) BR2=-1.0
      BR=BR1+BR2
      if(BR.lt.0.0) BR=0.0

      Nv=Natom-Nh
      Nsph=int(S(1))
      write(Iu4,762) IM,Etot,Nover, BR1,BR2,BR,
     &   DMW,Natom,Nv,(CMP(k:k),k=1,nCMP)
762   format(I5,F8.2,I4,3F6.2,F8.2,I5,I4,1x,70A)
C      write(Iu4,762) IM,Etot,Va,Nover, BR1,BR2,BR,
C     &   DMW,Natom,Nv,(CMP(k:k),k=1,nCMP)
C762   format(I5,2F8.2,I4,3F6.2,F8.2,I5,I4,1x,70A)

      read(Iu1,80,Err=150,End=200)
      do i=1,Nbond
      read(Iu1,*,Err=150,End=200)
      enddo
      return

150   write(*,*) 'Error in reading mol2 file: in getmol'
200   write(*,*) 'End of file: in getmol'
9999  return
      end 

